.. APIFairy documentation master file, created by
   sphinx-quickstart on Sun Sep 27 17:34:58 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

APIFairy
========

Welcome to the documentation for APIFairy, the minimalistic API framework for
Flask.

.. toctree::
   :maxdepth: 2

   intro
   guide
   decorators
   apifairy_class
